@@ -62,6 +62,11 @@ namespace smurf
             return rootFrame;
         };
 
+        std::string getURDFFilePath() const
+        {
+            return urdf_file_path;
+        };
+
         const ContactParams getContactParams(const std::string& collisionName, const std::string& linkName);
 
         /**
@@ -113,6 +118,7 @@ namespace smurf
          * - Loads the inertials
          */
         void loadFromSmurf(const std::string &path, std::string prefix = "");
+        configmaps::ConfigMap *smurfMap;
         
     protected:
         
@@ -126,7 +132,7 @@ namespace smurf
         
         Frame *rootFrame;
         urdf::ModelInterfaceSharedPtr model;
-        configmaps::ConfigMap *smurfMap;
+
         
         std::vector<smurf::Frame *> availableFrames;
         std::vector<smurf::StaticTransformation *> staticTransforms;
@@ -134,6 +140,7 @@ namespace smurf
         std::vector<smurf::Joint *> joints;
         std::vector<smurf::Sensor *> sensors;
         std::vector<smurf::Motor *> motors;
+        std::string urdf_file_path="";
         
         const bool debug = false;
 
